@@ -472,8 +472,7 @@ class ABF:
         nRows = self.channelCount
         nCols = int(self.dataPointCount/self.channelCount)
         raw = np.reshape(raw, (nCols, nRows))
-        raw = np.rot90(raw)
-        raw = raw[::-1]
+        raw = np.transpose(raw)
 
         # if data is int, scale it to float32 so we can scale it
         self.data = raw.astype(np.float32)
@@ -502,21 +501,21 @@ class ABF:
         self.sweepEpochs = pyabf.waveform.EpochSweepWaveform()
 
     @property
-    def headerText(self):
+    def headerText(self) -> str:
         """Return all header information as a text-formatted string."""
         return abfInfoPage(self).getText()
 
     @property
-    def headerMarkdown(self):
+    def headerMarkdown(self) -> str:
         """Return all header information as a markdown-formatted string."""
         return abfInfoPage(self).generateMarkdown()
 
     @property
-    def headerHTML(self):
+    def headerHTML(self) -> str:
         """Return all header information as a text-formatted string."""
         return abfInfoPage(self).generateHTML()
 
-    def headerLaunch(self):
+    def headerLaunch(self) -> None:
         """Display ABF header information in the web browser."""
         html = abfInfoPage(self).generateHTML()
 
@@ -534,7 +533,7 @@ class ABF:
             time.sleep(3)  # give it time to display before deleting the file
             os.remove(tmpFilePath)
 
-    def saveABF1(self, filePath: Union[str, pathlib.Path]):
+    def saveABF1(self, filePath: Union[str, pathlib.Path]) -> None:
         """
         Save this ABF file as an ABF1 file compatible with ClampFit and MiniAnalysis.
         Not all header values are saved, but the minimum necessary are to read sweep data.
@@ -556,7 +555,7 @@ class ABF:
             sweepData[sweep] = self.sweepY
         pyabf.abfWriter.writeABF1(sweepData, filePath, self.dataRate)
 
-    def launchInClampFit(self):
+    def launchInClampFit(self) -> None:
         """
         Launch the ABF in the default ABF viewing program (usually ClampFit) as
         if it were double-clicked in the windows explorer. 
@@ -564,7 +563,7 @@ class ABF:
         This assumes ClampFit is installed on your system and the default application
         for opening ABF files.
 
-        This will fail is ClampFit is already open.
+        This will fail if ClampFit is already open.
         """
         cmd = 'explorer.exe "%s"' % (self.abfFilePath)
         print("Launching %s.abf in ClampFit..." % (self.abfID))
@@ -575,7 +574,7 @@ class ABF:
                  sweepNumber: int,
                  channel: int = 0,
                  absoluteTime: bool = False,
-                 baseline: List[float] = [None, None]):
+                 baseline: List[float] = [None, None]) -> None:
         """
         Args:
 
@@ -642,9 +641,9 @@ class ABF:
             pointCount = self.sweepPointCount
         else:
             pointStart = 0
-            for i in range(1, sweepNumber):
-                pointStart += self._synchArraySection.lLength[i-1]
-            pointCount = self._synchArraySection.lLength[sweepNumber]
+            for i in range(sweepNumber):
+                pointStart += self._synchArraySection.lLength[i]//self.channelCount
+            pointCount = self._synchArraySection.lLength[sweepNumber]//self.channelCount
         pointEnd = pointStart + pointCount
 
         # load the actual sweep data
@@ -694,7 +693,7 @@ class ABF:
             return [None, None]
 
     @property
-    def sweepC(self):
+    def sweepC(self) -> np.ndarray:
         """Generate the sweep command waveform."""
         if hasattr(self, "_sweepC") and isinstance(self._sweepC, np.ndarray):
             # someone set a custom waveform, so always return it
@@ -727,7 +726,7 @@ class ABF:
             raise ValueError("sweepC.shape must match sweepY.shape")
         self._sweepC = sweepData
 
-    def sweepD(self, digOutNumber=0):
+    def sweepD(self, digOutNumber=0) -> np.ndarray:
         """Generate a waveform for the given digital output."""
         assert isinstance(self, pyabf.ABF)
         if (self.sweepChannel >= len(self.holdingCommand)):
@@ -738,17 +737,17 @@ class ABF:
         return sweepD
 
     @property
-    def sweepTimesSec(self):
+    def sweepTimesSec(self) -> np.ndarray:
         """Numpy array of sweep start times (in seconds)"""
         return np.arange(self.sweepCount)*self.sweepIntervalSec
 
     @property
-    def sweepTimesMin(self):
+    def sweepTimesMin(self) -> np.ndarray:
         """Numpy array of sweep start times (in minutes)"""
         return self.sweepTimesSec/60
 
     @property
-    def sweepDerivative(self):
+    def sweepDerivative(self) -> np.ndarray:
         """First derivative of sweepY (delta units / second)"""
         ddt = np.diff(self.sweepY)
         ddt = np.append(ddt, [ddt[-1]])
@@ -756,11 +755,11 @@ class ABF:
         return ddt
 
     @property
-    def fileGUID(self):
+    def fileGUID(self) -> str:
         return self._fileGUID
 
     @property
-    def md5(self):
+    def md5(self) -> str:
         """MD5 hash string of the whole ABF file."""
         if not hasattr(self, "_md5"):
             with open(self.abfFilePath, 'rb') as f:
@@ -769,9 +768,22 @@ class ABF:
         return self._md5
 
     @property
-    def fileUUID(self):
+    def fileUUID(self) -> str:
         """Create a unique ABF file ID using the MD5 of the whole file."""
         uuid = list(self.md5)
         for index in [8, 13, 18, 23]:
             uuid.insert(index, "-")
         return "".join(uuid)
+
+    @property
+    def sampleRate(self) -> int:
+        """Sample rate (Hz) for each channel"""
+        return self.dataRate
+
+    def getAllYs(self, channelIndex: int = 0) -> np.ndarray:
+        """Return data from all sweeps for the specified channel."""
+        return self.data[channelIndex]
+
+    def getAllXs(self, channelIndex: int = 0) -> np.ndarray:
+        """Return times from all sweeps for the specified channel."""
+        return np.arange(len(self.data[channelIndex]))/self.sampleRate
